pub fn forward_fill_start(old_block: U256, new_block: U256) -> U256Expand description
Returns the first block to backfill when rolling forward from old_block to new_block.
pub fn forward_fill_start(old_block: U256, new_block: U256) -> U256Returns the first block to backfill when rolling forward from old_block to new_block.