pub const fn history_storage_value(block_hash: B256) -> U256Expand description
Encodes a block hash as the history contract storage value.
pub const fn history_storage_value(block_hash: B256) -> U256Encodes a block hash as the history contract storage value.